"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.reloadWindowDelay = exports.interExtensionInstallDelay = exports.remoteEnvStabilizationDelay = exports.remoteExtensions = exports.remoteWorkDir = exports.healthCheckPollInterval = exports.healthCheckPollCount = exports.aistudioVersion = exports.socatDownloadUrl = exports.studioHealthCheckUrlTemplate = exports.startStudioUrl = exports.apiKeyUploadUrl = exports.apiBaseUrl = exports.sshServerAliveCountMax = exports.sshServerAliveInterval = exports.sshDefaultUser = exports.sshProxyPort = exports.sshProxyHost = exports.hasUsedFlagPath = exports.hasDownloadedFlagPath = exports.socatExePath = exports.socatTargetDirPath = exports.socatTargetDirName = exports.socatOriginalDirPath = exports.socatOriginalDirName = exports.socatZipPath = exports.socatZipFileName = exports.authorizedKeysPath = exports.sshConfigPath = exports.publicKeyPath = exports.privateKeyPath = exports.sshDir = exports.homeDir = void 0;
const path = require("path");
const os = require("os");
// ================================================================= //
//                          Path Configurations                        //
// ================================================================= //
exports.homeDir = os.homedir();
exports.sshDir = path.join(exports.homeDir, '.ssh');
// SSH Key Paths
exports.privateKeyPath = path.join(exports.sshDir, 'id_rsa');
exports.publicKeyPath = path.join(exports.sshDir, 'id_rsa.pub');
// SSH Config and Auth Paths
exports.sshConfigPath = path.join(exports.sshDir, 'config');
exports.authorizedKeysPath = path.join(exports.sshDir, 'authorized_keys');
// Socat-related Paths
exports.socatZipFileName = 'socat.zip';
exports.socatZipPath = path.join(exports.homeDir, exports.socatZipFileName);
exports.socatOriginalDirName = 'socat-1.7.3.0-windows-master';
exports.socatOriginalDirPath = path.join(exports.homeDir, exports.socatOriginalDirName);
exports.socatTargetDirName = 'socat';
exports.socatTargetDirPath = path.join(exports.homeDir, exports.socatTargetDirName);
exports.socatExePath = path.join(exports.socatTargetDirPath, 'socat.exe');
// Flag files to check if download/setup has been completed
exports.hasDownloadedFlagPath = path.join(exports.sshDir, 'hasDownloaded.dat');
exports.hasUsedFlagPath = path.join(exports.sshDir, 'hasUsed.dat');
// ================================================================= //
//                       SSH Connection Settings                       //
// ================================================================= //
exports.sshProxyHost = '39.104.162.137';
exports.sshProxyPort = '10002';
exports.sshDefaultUser = 'aiuser';
exports.sshServerAliveInterval = 60;
exports.sshServerAliveCountMax = 3;
// ================================================================= //
//                        API & URL Configurations                     //
// ================================================================= //
exports.apiBaseUrl = "https://bigquant.com";
exports.apiKeyUploadUrl = `${exports.apiBaseUrl}/bigapis/aistudio/v1/files/authorized_keys`;
exports.startStudioUrl = `${exports.apiBaseUrl}/bigapis/aistudio/v1/studios/@default`;
const studioHealthCheckUrlTemplate = (id) => `${exports.apiBaseUrl}/aistudio/studios/${id}/healthz`;
exports.studioHealthCheckUrlTemplate = studioHealthCheckUrlTemplate;
exports.socatDownloadUrl = `${exports.apiBaseUrl}/s6/public/download/socat-1.7.3.0-windows-master.zip`;
// ================================================================= //
//                      Application Logic Settings                     //
// ================================================================= //
// AI Studio Settings
exports.aistudioVersion = 300;
exports.healthCheckPollCount = 20;
exports.healthCheckPollInterval = 1000; // in milliseconds
// Remote Environment
exports.remoteWorkDir = '/home/aiuser/work';
// VS Code Remote Extensions to Install
exports.remoteExtensions = [
    { id: 'ms-ceintl.vscode-language-pack-zh-hans', name: 'Chinese (Simplified) Language Pack' },
    { id: 'ms-python.python', name: 'Python' },
    { id: 'ms-toolsai.jupyter', name: 'Jupyter' },
    { id: 'ms-toolsai.jupyter-renderers', name: 'Jupyter Slide Show' },
    { id: 'ms-toolsai.vscode-jupyter-cell-tags', name: 'Jupyter Cell Tags' }
];
// Delays for extension installation logic
exports.remoteEnvStabilizationDelay = 10000; // ms
exports.interExtensionInstallDelay = 1000; // ms
exports.reloadWindowDelay = 2000; // ms
//# sourceMappingURL=00_configurations.js.map