"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.downloadSocat = downloadSocat;
const vscode = require("vscode");
const os = require("os");
const fs = require("fs");
const axios_1 = require("axios");
const child_process_1 = require("child_process");
const _00_configurations_1 = require("./00_configurations");
/**
 * 根据不同操作系统处理 socat 连接工具。
 */
function downloadSocat(postStatus) {
    return __awaiter(this, void 0, void 0, function* () {
        const platform = os.platform();
        postStatus(`检查操作系统，当前为: ${platform}`);
        switch (platform) {
            case 'win32':
                if (!fs.existsSync(_00_configurations_1.hasDownloadedFlagPath) || !fs.existsSync(_00_configurations_1.hasUsedFlagPath)) {
                    postStatus("在 Windows 上下载连接工具(socat)...");
                    yield vscode.window.withProgress({ location: vscode.ProgressLocation.Notification, title: `Downloading socat...`, cancellable: false }, (progress) => __awaiter(this, void 0, void 0, function* () {
                        const response = yield (0, axios_1.default)({ method: 'GET', url: _00_configurations_1.socatDownloadUrl, responseType: 'stream' });
                        if (response.status >= 200 && response.status < 300) {
                            const totalBytes = response.headers['content-length'] ? parseInt(response.headers['content-length'], 10) : 0;
                            let downloadedBytes = 0;
                            const writer = fs.createWriteStream(_00_configurations_1.socatZipPath);
                            response.data.on('data', (chunk) => {
                                downloadedBytes += chunk.length;
                                if (totalBytes > 0) {
                                    progress.report({ increment: (chunk.length / totalBytes) * 100 });
                                }
                            });
                            response.data.pipe(writer);
                            yield new Promise((resolve, reject) => {
                                writer.on('finish', resolve);
                                writer.on('error', reject);
                            });
                            vscode.window.showInformationMessage(`下载成功: socat.zip`);
                        }
                        else {
                            throw new Error(`下载失败，服务器状态: ${response.status}`);
                        }
                    }));
                }
                break;
            case 'darwin': // macOS
                postStatus("在 macOS 上使用 Homebrew 安装 socat...");
                yield vscode.window.withProgress({ location: vscode.ProgressLocation.Notification, title: 'Installing socat via Homebrew...', cancellable: false }, () => __awaiter(this, void 0, void 0, function* () {
                    yield new Promise((resolve, reject) => {
                        const command = 'HOMEBREW_NO_AUTO_UPDATE=1 brew install socat';
                        (0, child_process_1.exec)(command, (error, stdout, stderr) => {
                            if (error) {
                                vscode.window.showErrorMessage(`socat 安装失败: ${stderr}`);
                                postStatus(`socat 安装失败: ${stderr}`);
                                reject(error);
                            }
                            else {
                                vscode.window.showInformationMessage('socat 安装成功!');
                                postStatus("socat 安装成功。");
                                resolve();
                            }
                        });
                    });
                }));
                break;
            case 'linux':
                postStatus("Linux 系统，跳过 socat 安装。");
                vscode.window.showInformationMessage('Linux 系统，跳过 socat 安装。');
                break;
            default:
                const unsupportedMessage = `不支持的操作系统: ${platform}`;
                postStatus(unsupportedMessage);
                vscode.window.showErrorMessage(unsupportedMessage);
                throw new Error(unsupportedMessage);
        }
    });
}
//# sourceMappingURL=04_download-socat.js.map