"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ensureRemoteExtensionsAreInstalled = ensureRemoteExtensionsAreInstalled;
const vscode = require("vscode");
const _00_configurations_1 = require("./00_configurations");
/**
 * Installs all required extensions in the remote environment.
 * This function runs every time to ensure the environment is correctly set up.
 */
function ensureRemoteExtensionsAreInstalled() {
    return __awaiter(this, void 0, void 0, function* () {
        console.log("BigQuant Connector: 开始安装远程插件...");
        yield vscode.window.withProgress({
            location: vscode.ProgressLocation.Notification,
            title: "正在配置远程开发环境",
            cancellable: false
        }, (progress) => __awaiter(this, void 0, void 0, function* () {
            for (let i = 0; i < _00_configurations_1.remoteExtensions.length; i++) {
                const extension = _00_configurations_1.remoteExtensions[i];
                const progressMessage = `正在安装插件: ${extension.name} (${i + 1}/${_00_configurations_1.remoteExtensions.length})`;
                progress.report({ message: progressMessage });
                try {
                    // 使用 VS Code 命令安装插件
                    yield vscode.commands.executeCommand('workbench.extensions.installExtension', extension.id);
                    console.log(`BigQuant Connector: 成功提交安装请求 ${extension.id}`);
                }
                catch (error) {
                    console.error(`BigQuant Connector: 安装插件 ${extension.id} 失败`, error);
                    // 不向用户显示错误，因为这可能是因为插件已经安装
                }
            }
        }));
        console.log("BigQuant Connector: 远程插件安装请求已全部提交。");
        vscode.window.showInformationMessage('远程开发环境配置完成');
    });
}
//# sourceMappingURL=10_install-remote-extensions.js.map