"use strict";
//Configuration配置
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.cacheValidationDelay = exports.validateCacheOnStartup = exports.reloadWindowDelay = exports.interExtensionInstallDelay = exports.remoteEnvStabilizationDelay = exports.remoteExtensions = exports.remoteWorkDir = exports.healthCheckPollInterval = exports.healthCheckPollCount = exports.aistudioVersion = exports.socatDownloadUrl = exports.studioHealthCheckUrlTemplate = exports.startStudioUrl = exports.apiKeyUploadUrl = exports.apiBaseUrl = exports.sshServerAliveCountMax = exports.sshServerAliveInterval = exports.sshDefaultUser = exports.sshProxyPort = exports.sshProxyHost = exports.hasUsedFlagPath = exports.hasDownloadedFlagPath = exports.socatExePath = exports.socatTargetDirPath = exports.socatTargetDirName = exports.socatOriginalDirPath = exports.socatOriginalDirName = exports.socatZipPath = exports.socatZipFileName = exports.authorizedKeysPath = exports.sshConfigPath = exports.publicKeyPath2 = exports.privateKeyPath2 = exports.publicKeyPath = exports.privateKeyPath = exports.sshDir = exports.homeDir = void 0;
exports.ensureDefaultTerminalProfileIsConfigured = ensureDefaultTerminalProfileIsConfigured;
const path = require("path");
const os = require("os");
const vscode = require("vscode");
// ================================================================= //
//                          Path Configurations                        //
// ================================================================= //
exports.homeDir = os.homedir();
exports.sshDir = path.join(exports.homeDir, '.ssh');
// SSH Key Paths
exports.privateKeyPath = path.join(exports.sshDir, 'id_ed25519');
exports.publicKeyPath = path.join(exports.sshDir, 'id_ed25519.pub');
exports.privateKeyPath2 = path.join(exports.sshDir, 'id_rsa');
exports.publicKeyPath2 = path.join(exports.sshDir, 'id_rsa.pub');
// SSH Config and Auth Paths
exports.sshConfigPath = path.join(exports.sshDir, 'config');
exports.authorizedKeysPath = path.join(exports.sshDir, 'authorized_keys');
// Socat-related Paths
exports.socatZipFileName = 'socat.zip';
exports.socatZipPath = path.join(exports.homeDir, exports.socatZipFileName);
exports.socatOriginalDirName = 'socat-1.7.3.0-windows-master';
exports.socatOriginalDirPath = path.join(exports.homeDir, exports.socatOriginalDirName);
exports.socatTargetDirName = 'socat';
exports.socatTargetDirPath = path.join(exports.homeDir, exports.socatTargetDirName);
exports.socatExePath = path.join(exports.socatTargetDirPath, 'socat.exe');
// Flag files to check if download/setup has been completed
exports.hasDownloadedFlagPath = path.join(exports.sshDir, 'hasDownloaded.dat');
exports.hasUsedFlagPath = path.join(exports.sshDir, 'hasUsed.dat');
// ================================================================= //
//                       SSH Connection Settings                       //
// ================================================================= //
exports.sshProxyHost = '39.104.162.137';
exports.sshProxyPort = '10002';
exports.sshDefaultUser = 'aiuser';
exports.sshServerAliveInterval = 60;
exports.sshServerAliveCountMax = 3;
// ================================================================= //
//                        API & URL Configurations                     //
// ================================================================= //
exports.apiBaseUrl = "https://bigquant.com";
exports.apiKeyUploadUrl = `${exports.apiBaseUrl}/bigapis/aistudio/v1/files/authorized_keys`;
exports.startStudioUrl = `${exports.apiBaseUrl}/bigapis/aistudio/v1/studios/@default`;
const studioHealthCheckUrlTemplate = (id) => `${exports.apiBaseUrl}/aistudio/studios/${id}/healthz`;
exports.studioHealthCheckUrlTemplate = studioHealthCheckUrlTemplate;
exports.socatDownloadUrl = `${exports.apiBaseUrl}/s6/public/download/socat-1.7.3.0-windows-master.zip`;
// ================================================================= //
//                      Application Logic Settings                     //
// ================================================================= //
// AI Studio Settings
exports.aistudioVersion = 300;
exports.healthCheckPollCount = 30;
exports.healthCheckPollInterval = 2000; // in milliseconds
// Remote Environment
exports.remoteWorkDir = '/home/aiuser/work';
// VS Code Remote Extensions to Install (只包含需要在远程运行的插件)
exports.remoteExtensions = [
    // 注意：中文语言包是UI插件，只在本地运行，不应在远程安装
    // { id: 'ms-ceintl.vscode-language-pack-zh-hans', name: 'Chinese (Simplified) Language Pack' },
    { id: 'ms-python.python', name: 'Python' },
    { id: 'ms-toolsai.jupyter', name: 'Jupyter' },
    { id: 'ms-toolsai.jupyter-renderers', name: 'Jupyter Slide Show' },
    { id: 'ms-toolsai.vscode-jupyter-cell-tags', name: 'Jupyter Cell Tags' }
];
// Delays for extension installation logic
exports.remoteEnvStabilizationDelay = 10000; // ms
exports.interExtensionInstallDelay = 1000; // ms
exports.reloadWindowDelay = 2000; // ms
// Extension cache validation settings
exports.validateCacheOnStartup = true; // 是否在启动时验证缓存准确性
exports.cacheValidationDelay = 5000; // 延迟验证时间 (ms)
// ================================================================= //
//                      VS Code Configuration Functions             //
// ================================================================= //
function ensureDefaultTerminalProfileIsConfigured(outputChannel, postStatus) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const config = vscode.workspace.getConfiguration('terminal.integrated');
            const currentProfile = config.get('defaultProfile.windows');
            if (currentProfile !== 'Command Prompt') {
                postStatus("正在配置默认终端为 Command Prompt...");
                yield config.update('defaultProfile.windows', 'Command Prompt', vscode.ConfigurationTarget.Global);
                outputChannel.appendLine("已将默认终端配置为 Command Prompt");
                return true; // Configuration was changed
            }
            return false; // No change needed
        }
        catch (error) {
            outputChannel.appendLine(`配置终端时发生错误: ${error}`);
            return false;
        }
    });
}
//# sourceMappingURL=configurations.js.map