"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.configureSshProxy = configureSshProxy;
const fsp = require("fs/promises");
const fs = require("fs");
const os = require("os");
const configurations_1 = require("./configurations");
/**
 * Step6: 配置 SSH config 文件以使用 socat 代理。
 */
function configureSshProxy(username, postStatus) {
    return __awaiter(this, void 0, void 0, function* () {
        postStatus("配置SSH代理...");
        let proxyCommand;
        const isWindows = os.platform() === 'win32';
        if (isWindows) {
            const escapedSocatPath = configurations_1.socatExePath.replace(/\\/g, '\\\\');
            proxyCommand = `"${escapedSocatPath}" - PROXY:${configurations_1.sshProxyHost}:%h:%p,proxyport=${configurations_1.sshProxyPort}`;
        }
        else {
            // For macOS and Linux, assume 'socat' is in the PATH
            proxyCommand = `socat - PROXY:${configurations_1.sshProxyHost}:%h:%p,proxyport=${configurations_1.sshProxyPort}`;
        }
        const configContent = `\nHost ${username}.bigquant\n\tUser ${configurations_1.sshDefaultUser}\n\tHostName ${username}.bigquant\n\tProxyCommand ${proxyCommand}\n\tServerAliveInterval ${configurations_1.sshServerAliveInterval}\n\tServerAliveCountMax ${configurations_1.sshServerAliveCountMax}\n\tTCPKeepAlive yes\n\tStrictHostKeyChecking no\n\tUserKnownHostsFile /dev/null\n\tForwardAgent yes`;
        if (fs.existsSync(configurations_1.sshConfigPath)) {
            const existingContent = yield fsp.readFile(configurations_1.sshConfigPath, 'utf8');
            if (!existingContent.includes(`Host ${username}.bigquant`)) {
                yield fsp.appendFile(configurations_1.sshConfigPath, configContent);
            }
        }
        else {
            yield fsp.writeFile(configurations_1.sshConfigPath, configContent, { mode: 0o600 });
        }
    });
}
//# sourceMappingURL=configure-ssh.js.map