"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.openAiStudio = openAiStudio;
const vscode = require("vscode");
const axios_1 = require("axios");
const configurations_1 = require("./configurations");
/**
 * Step8: 请求打开服务器上的 AI Studio 并轮询其健康状态。
 */
function openAiStudio(context, postStatus) {
    return __awaiter(this, void 0, void 0, function* () {
        postStatus("正在打开云端 AI Studio...");
        const token = yield context.secrets.get("token");
        const id = yield context.secrets.get("id");
        if (!token || !id)
            throw new Error("无法获取用户 token 或 id");
        const axiosConfig = { headers: { 'Cookie': `bigjwt=${token}` } };
        yield axios_1.default.post(configurations_1.startStudioUrl, { 'aistudio_version': configurations_1.aistudioVersion }, axiosConfig);
        vscode.window.showInformationMessage('打开 AI Studio 请求已发送!');
        postStatus("等待云端服务就绪...");
        for (let i = 0; i < configurations_1.healthCheckPollCount; i++) {
            try {
                const health = yield axios_1.default.get((0, configurations_1.studioHealthCheckUrlTemplate)(id), axiosConfig);
                if (health.status === 200) {
                    postStatus("云端服务已就绪！");
                    return;
                }
            }
            catch (error) {
                // 忽略错误，继续轮询
            }
            if (i === configurations_1.healthCheckPollCount - 1) {
                throw new Error('心跳包检查失败，云端服务未能在指定时间内就绪。');
            }
            yield new Promise(resolve => setTimeout(resolve, configurations_1.healthCheckPollInterval));
        }
    });
}
//# sourceMappingURL=open-aistudio.js.map