import * as vscode from 'vscode';

/**
 * Step1: 检查并自动安装 Remote-SSH 插件。
 * @returns {Promise<boolean>} 如果依赖项已准备好，则返回 true；否则返回 false。
 */
export async function checkAndInstallDependencies(postStatus: (text: string) => void): Promise<boolean> {
    postStatus("检查环境依赖...");
    let remoteSshExtension = vscode.extensions.getExtension('ms-vscode-remote.remote-ssh');

    if (!remoteSshExtension) {
        postStatus("未找到 Remote-SSH 插件，正在自动安装...");
        try {
            await vscode.window.withProgress({
                location: vscode.ProgressLocation.Notification,
                title: '正在安装 Remote - SSH 插件...',
                cancellable: false
            }, async (progress) => {
                await vscode.commands.executeCommand('workbench.extensions.installExtension', 'ms-vscode-remote.remote-ssh');
                progress.report({ message: '安装完成。' });
            });
        } catch (error) {
            console.error("自动安装 Remote-SSH 失败:", error);
            postStatus("自动安装失败，请手动安装。");
            vscode.window.showErrorMessage('自动安装 "Remote - SSH" 失败，请从插件市场手动安装。');
            const uri = vscode.Uri.parse('vscode:extension/ms-vscode-remote.remote-ssh');
            await vscode.env.openExternal(uri);
        }
        return false; // 需要用户操作（重启或手动安装），所以当前流程不能继续
    }

    postStatus("环境检查通过。");
    return true; // 依赖项已满足
}