//Configuration配置

import * as path from 'path';
import * as os from 'os';
import * as vscode from 'vscode';

// ================================================================= //
//                          Path Configurations                        //
// ================================================================= //

export const homeDir = os.homedir();
export const sshDir = path.join(homeDir, '.ssh');

// SSH Key Paths
export const privateKeyPath = path.join(sshDir, 'id_ed25519');
export const publicKeyPath = path.join(sshDir, 'id_ed25519.pub');
export const privateKeyPath2 = path.join(sshDir, 'id_rsa');
export const publicKeyPath2 = path.join(sshDir, 'id_rsa.pub');

// SSH Config and Auth Paths
export const sshConfigPath = path.join(sshDir, 'config');
export const authorizedKeysPath = path.join(sshDir, 'authorized_keys');

// Socat-related Paths
export const socatZipFileName = 'socat.zip';
export const socatZipPath = path.join(homeDir, socatZipFileName);
export const socatOriginalDirName = 'socat-1.7.3.0-windows-master';
export const socatOriginalDirPath = path.join(homeDir, socatOriginalDirName);
export const socatTargetDirName = 'socat';
export const socatTargetDirPath = path.join(homeDir, socatTargetDirName);
export const socatExePath = path.join(socatTargetDirPath, 'socat.exe');

// Flag files to check if download/setup has been completed
export const hasDownloadedFlagPath = path.join(sshDir, 'hasDownloaded.dat');
export const hasUsedFlagPath = path.join(sshDir, 'hasUsed.dat');


// ================================================================= //
//                       SSH Connection Settings                       //
// ================================================================= //

export const sshProxyHost = '39.104.162.137';
export const sshProxyPort = '10002';
export const sshDefaultUser = 'aiuser';
export const sshServerAliveInterval = 60;
export const sshServerAliveCountMax = 3;


// ================================================================= //
//                        API & URL Configurations                     //
// ================================================================= //

export const apiBaseUrl = "https://bigquant.com";
export const apiKeyUploadUrl = `${apiBaseUrl}/bigapis/aistudio/v1/files/authorized_keys`;
export const startStudioUrl = `${apiBaseUrl}/bigapis/aistudio/v1/studios/@default`;
export const studioHealthCheckUrlTemplate = (id: string) => `${apiBaseUrl}/aistudio/studios/${id}/healthz`;
export const socatDownloadUrl = `${apiBaseUrl}/s6/public/download/socat-1.7.3.0-windows-master.zip`;


// ================================================================= //
//                      Application Logic Settings                     //
// ================================================================= //

// AI Studio Settings
export const aistudioVersion = 300;
export const healthCheckPollCount = 30;
export const healthCheckPollInterval = 2000; // in milliseconds

// Remote Environment
export const remoteWorkDir = '/home/aiuser/work';

// VS Code Remote Extensions to Install (只包含需要在远程运行的插件)
export const remoteExtensions = [
    // 注意：中文语言包是UI插件，只在本地运行，不应在远程安装
    // { id: 'ms-ceintl.vscode-language-pack-zh-hans', name: 'Chinese (Simplified) Language Pack' },
    { id: 'ms-python.python', name: 'Python' },
    { id: 'ms-toolsai.jupyter', name: 'Jupyter' },
    { id: 'ms-toolsai.jupyter-renderers', name: 'Jupyter Slide Show' },
    { id: 'ms-toolsai.vscode-jupyter-cell-tags', name: 'Jupyter Cell Tags' }
];

// Delays for extension installation logic
export const remoteEnvStabilizationDelay = 10000; // ms
export const interExtensionInstallDelay = 1000; // ms
export const reloadWindowDelay = 2000; // ms

// Extension cache validation settings
export const validateCacheOnStartup = true; // 是否在启动时验证缓存准确性
export const cacheValidationDelay = 5000; // 延迟验证时间 (ms)

// ================================================================= //
//                      VS Code Configuration Functions             //
// ================================================================= //

export async function ensureDefaultTerminalProfileIsConfigured(
    outputChannel: vscode.OutputChannel,
    postStatus: (text: string) => void
): Promise<boolean> {
    try {
        const config = vscode.workspace.getConfiguration('terminal.integrated');
        const currentProfile = config.get('defaultProfile.windows');
        
        if (currentProfile !== 'Command Prompt') {
            postStatus("正在配置默认终端为 Command Prompt...");
            await config.update('defaultProfile.windows', 'Command Prompt', vscode.ConfigurationTarget.Global);
            outputChannel.appendLine("已将默认终端配置为 Command Prompt");
            return true; // Configuration was changed
        }
        
        return false; // No change needed
    } catch (error) {
        outputChannel.appendLine(`配置终端时发生错误: ${error}`);
        return false;
    }
}
