import * as fsp from 'fs/promises';
import * as fs from 'fs';
import * as os from 'os';
import { 
    sshConfigPath, 
    socatExePath, 
    sshProxyHost, 
    sshProxyPort, 
    sshDefaultUser, 
    sshServerAliveInterval, 
    sshServerAliveCountMax 
} from './configurations';

/**
 * Step6: 配置 SSH config 文件以使用 socat 代理。
 */
export async function configureSshProxy(username: string, postStatus: (text: string) => void): Promise<void> {
    postStatus("配置SSH代理...");

    let proxyCommand: string;
    const isWindows = os.platform() === 'win32';

    if (isWindows) {
        const escapedSocatPath = socatExePath.replace(/\\/g, '\\\\');
        proxyCommand = `"${escapedSocatPath}" - PROXY:${sshProxyHost}:%h:%p,proxyport=${sshProxyPort}`;
    } else {
        // For macOS and Linux, assume 'socat' is in the PATH
        proxyCommand = `socat - PROXY:${sshProxyHost}:%h:%p,proxyport=${sshProxyPort}`;
    }

    const configContent = `\nHost ${username}.bigquant\n\tUser ${sshDefaultUser}\n\tHostName ${username}.bigquant\n\tProxyCommand ${proxyCommand}\n\tServerAliveInterval ${sshServerAliveInterval}\n\tServerAliveCountMax ${sshServerAliveCountMax}\n\tTCPKeepAlive yes\n\tStrictHostKeyChecking no\n\tUserKnownHostsFile /dev/null\n\tForwardAgent yes`;
    
    if (fs.existsSync(sshConfigPath)) {
        const existingContent = await fsp.readFile(sshConfigPath, 'utf8');
        if (!existingContent.includes(`Host ${username}.bigquant`)) {
            await fsp.appendFile(sshConfigPath, configContent);
        }
    } else {
        await fsp.writeFile(sshConfigPath, configContent, { mode: 0o600 });
    }
}
