import * as vscode from 'vscode';
import * as os from 'os';
import * as fs from 'fs';
import * as fsp from 'fs/promises';
import * as unzipper from 'unzipper';
import { hasDownloadedFlagPath, hasUsedFlagPath, socatZipPath, homeDir, socatOriginalDirPath, socatTargetDirPath } from './configurations';

/**
 * Step5: 解压 socat.zip 并重命名文件夹、删除残留。
 */
export async function extractAndRenameSocat(postStatus: (text: string) => void): Promise<void> {
    if (os.platform() === 'win32' && (!fs.existsSync(hasDownloadedFlagPath) || !fs.existsSync(hasUsedFlagPath))) {
        postStatus("解压并配置工具...");
        
        await fsp.access(socatZipPath, fs.constants.F_OK); // 确认文件存在

        await vscode.window.withProgress({ location: vscode.ProgressLocation.Notification, title: `正在解压...`, cancellable: false }, async () => {
            await fs.createReadStream(socatZipPath).pipe(unzipper.Extract({ path: homeDir })).promise();
        });

        await fsp.chmod(socatOriginalDirPath, 0o777);
        await fsp.rename(socatOriginalDirPath, socatTargetDirPath);

        // 删除残留的安装包
        postStatus("删除残留安装包...");
        await fsp.rm(socatZipPath);

        //写标志文件
        await fsp.writeFile(hasDownloadedFlagPath, 'downloaded', { mode: 0o600 });
    }
}
