import * as vscode from 'vscode';
import axios from 'axios';
import { 
    startStudioUrl, 
    studioHealthCheckUrlTemplate, 
    aistudioVersion, 
    healthCheckPollCount, 
    healthCheckPollInterval 
} from './configurations';

/**
 * Step8: 请求打开服务器上的 AI Studio 并轮询其健康状态。
 */
export async function openAiStudio(context: vscode.ExtensionContext, postStatus: (text: string) => void): Promise<void> {
    postStatus("正在打开云端 AI Studio...");
    const token = await context.secrets.get("token");
    const id = await context.secrets.get("id");
    if (!token || !id) throw new Error("无法获取用户 token 或 id");

    const axiosConfig = { headers: { 'Cookie': `bigjwt=${token}` } };
    
    await axios.post(startStudioUrl, { 'aistudio_version': aistudioVersion }, axiosConfig);
    vscode.window.showInformationMessage('打开 AI Studio 请求已发送!');

    postStatus("等待云端服务就绪...");
    for (let i = 0; i < healthCheckPollCount; i++) {
        try {
            const health = await axios.get(studioHealthCheckUrlTemplate(id), axiosConfig);
            if (health.status === 200) {
                postStatus("云端服务已就绪！");
                return;
            }
        } catch (error) {
            // 忽略错误，继续轮询
        }
        if (i === healthCheckPollCount - 1) {
            throw new Error('心跳包检查失败，云端服务未能在指定时间内就绪。');
        }
        await new Promise(resolve => setTimeout(resolve, healthCheckPollInterval));
    }
}
