import * as fsp from 'fs/promises';
import * as fs from 'fs';
import * as vscode from 'vscode';
import axios from 'axios';
import { publicKeyPath, publicKeyPath2, authorizedKeysPath, apiKeyUploadUrl } from './configurations';

/**
 * Step7: 上传公钥到服务器并更新本地 authorized_keys。
 */
export async function uploadPublicKey(context: vscode.ExtensionContext, postStatus: (text: string) => void): Promise<void> {
    postStatus("上传公钥授权...");

    let publicKey = "";
    if(fs.existsSync(publicKeyPath)){
        publicKey = await fsp.readFile(publicKeyPath, 'utf8');
    }
    else{
        publicKey = await fsp.readFile(publicKeyPath2, 'utf8');
    }
    await fsp.writeFile(authorizedKeysPath, publicKey, { mode: 0o600 });

    const token = await context.secrets.get("token");
    await axios.post(apiKeyUploadUrl, { 'pub_key': publicKey }, { headers: { 'Cookie': `bigjwt=${token}` } });
    
    vscode.window.showInformationMessage('公钥授权成功！');
}
